/*
 * Copyright (C) 2004-2005 the xine-project
 *
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License as 
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 *
 * $Id: time_widget.h,v 1.2 2005/01/12 18:45:04 dsalt Exp $
 *
 * a nice black time display area
 */
#ifndef HAVE_TIME_WIDGET_H
#define HAVE_TIME_WIDGET_H

#include <gtk/gtk.h>

typedef struct time_widget_s time_widget_t;

time_widget_t *create_time_widget (GtkWidget **w);

void postinit_time_widget (time_widget_t *tw);

#endif
